pub const fn cmsg_space(data_len: usize) -> usizeAvailable on neither FreeBSD nor Fuchsia nor GNU/Hurd nor Play Station Vita nor Redox OS.
Given a payload of data_len, returns the number of bytes a control message occupies.
i.e. it includes the header, the data and the alignments.